
#ifndef KDEGAMESPRIVATE_EXPORT_H
#define KDEGAMESPRIVATE_EXPORT_H

#ifdef KDEGAMESPRIVATE_STATIC_DEFINE
#  define KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_NO_EXPORT
#else
#  ifndef KDEGAMESPRIVATE_EXPORT
#    ifdef KDEGamesPrivate_EXPORTS
        /* We are building this library */
#      define KDEGAMESPRIVATE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDEGAMESPRIVATE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDEGAMESPRIVATE_NO_EXPORT
#    define KDEGAMESPRIVATE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED
#  define KDEGAMESPRIVATE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT
#  define KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT
#  define KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDEGAMESPRIVATE_NO_DEPRECATED
#    define KDEGAMESPRIVATE_NO_DEPRECATED
#  endif
#endif
#include <kdegames_version.h>

#define KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KDEGAMESPRIVATE_NO_DEPRECATED)
#  undef KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT
#elif defined(KDEGAMESPRIVATE_NO_DEPRECATED_WARNINGS)
#  define KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT
#else
#  define KDEGAMESPRIVATE_DEPRECATED KDEGAMESPRIVATE_DECL_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KDEGAMESPRIVATE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KDEGAMESPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KDEGAMESPRIVATE_NO_DEPRECATED
#  define KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT KDEGAMES_VERSION
#endif
#ifdef KDEGAMESPRIVATE_NO_DEPRECATED_WARNINGS
#  define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE
#  ifdef KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE KDEGAMES_VERSION
#  endif
#endif

#ifndef KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KDEGAMESPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KDEGAMESPRIVATE_EXPORT_H */
